struct ModuleContext {
owner: Trusted<GlobalScope>,
data: Vec<u8>,
metadata: Option<Metadata>,
module_request: (ServoUrl, ModuleType),
options: ScriptFetchOptions,
status: Result<(), NetworkError>,
introduction_type: Option<&'static CStr>,
policy_container: Option<PolicyContainer>,
}Expand description
The context required for asynchronously loading an external module script source.
Fields
owner: Trusted<GlobalScope>The owner of the module that initiated the request.
data: Vec<u8>The response body received to date.
metadata: Option<Metadata>The response metadata received to date.
module_request: (ServoUrl, ModuleType)Url and type of the requested module.
options: ScriptFetchOptionsOptions for the current script fetch
status: Result<(), NetworkError>Indicates whether the request failed, and why
introduction_type: Option<&'static CStr>introductionType value to set in the CompileOptionsWrapper.
policy_container: Option<PolicyContainer>Trait Implementations
Sourceimpl FetchResponseListener for ModuleContext
impl FetchResponseListener for ModuleContext
Sourcefn process_response_eof(
self,
cx: &mut JSContext,
_: RequestId,
response: Result<(), NetworkError>,
timing: ResourceFetchTiming,
)
fn process_response_eof( self, cx: &mut JSContext, _: RequestId, response: Result<(), NetworkError>, timing: ResourceFetchTiming, )
fn process_request_body(&mut self, _: RequestId)
fn process_response( &mut self, _: &mut JSContext, _: RequestId, metadata: Result<FetchMetadata, NetworkError>, )
fn process_response_chunk( &mut self, _: &mut JSContext, _: RequestId, chunk: Vec<u8>, )
fn process_csp_violations( &mut self, _request_id: RequestId, violations: Vec<Violation>, )
Sourcefn should_invoke(&self) -> bool
fn should_invoke(&self) -> bool
A gating mechanism that runs before invoking the listener methods on the target
thread. If the
should_invoke method returns false, the listener does not receive
the notification.Sourceimpl ResourceTimingListener for ModuleContext
impl ResourceTimingListener for ModuleContext
fn resource_timing_information(&self) -> (InitiatorType, ServoUrl)
fn resource_timing_global(&self) -> DomRoot<GlobalScope>